@@ -931,6 +931,14 @@ class Table:
         return self.database.delete_query(self)
         # return self.database.delete_query(self.table_name)
 
+    def truncate(self):
+        '''Truncate this tables data'''
+        query = f'''
+SET FOREIGN_KEY_CHECKS=0;
+TRUNCATE TABLE {self.name};
+SET FOREIGN_KEY_CHECKS=1;'''
+        self.database.run(query)
+
     @property
     def cerberus_validation_schema(self):
         '''
