@@ -58,6 +58,9 @@ def gen_variations(value):
     varis.append(upper)
     varis.append(snake_case)
     varis.append(screaming_snake_case)
+    varis.append(_csu.to_camel_case(value))
+    varis.append(_csu.to_pascal_case(value))
+    varis.append(_csu.to_kebab_case(value))
     return varis
 
 def number(minimum=1,maximum=100):
@@ -290,6 +293,11 @@ def text(minimum=10,maximum=500,null_bias=0):
     val = val.replace("'","")
     return val
 
+def ip_address(bias=100):
+    if faker().boolean(bias):
+        return faker().ipv4()
+    return None
+
 def phone(bias=100):
     '''
         Generate a random phone number or None.
@@ -844,7 +852,7 @@ def _rand_option(options):
     except IndexError:
         return _rand_option(options)
 
-def female_first_last_name():
+def female_first_last_name()->tuple:
     '''
         Generate a random female first and last name
 
@@ -868,7 +876,30 @@ def female_first_last_name():
     fake = faker()
     return (fake.first_name_female(), fake.last_name())
 
-def male_first_last_name():
+def last_name():
+    '''
+        Generate a random last name.
+        ----------
+
+        Return {str}
+        ----------------------
+        A randomly generate last name.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-15-2022 18:42:34
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: last_name
+        * @TODO []: documentation for last_name
+    '''
+    fake = faker()
+    return fake.last_name()
+
+
+
+def male_first_last_name()->tuple:
     '''
         Generate a random male first and last name
 
