@@ -4,6 +4,7 @@
 
 # import json
 import re
+from typing import Iterable
 # import importlib
 # from dataclasses import dataclass
 # from posixpath import split
@@ -34,6 +35,8 @@ class Name:
         '''A list of all variations of the name'''
         self.name = name
         '''The unmodified name'''
+        self.private = f"_{name}"
+        '''The name with a single leading underscore'''
         self.pascal = self.__Pascal(self,name)
         self.snake = self.__Snake(self,name)
         self.camel = self.__Camel(self,name)
@@ -53,8 +56,8 @@ class Name:
         # self.names.append(self.snake.name)
         # self.names.append(self.snake.singular)
         # self.names.append(self.snake.plural)
-        self.settings = {}
-        self.data = {}
+        # self.settings = {}
+        # self.data = {}
 
     class __Camel:
         name:str = None
@@ -106,8 +109,42 @@ class Name:
             self.main.names.append(self.singular)
             self.main.names.append(self.plural)
 
+            self._misspellings:Iterable[str] = None
 
 
+    @property
+    def misspellings(self)->list:
+        '''
+            Get the misspellings value.
+
+            `default`:None
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 01-06-2023 16:31:05
+            `@memberOf`: PostArg
+            `@property`: misspellings
+        '''
+        if self._misspellings is not None:
+            return self._misspellings
+        value = _csu.variations(self.name.name,)
+        return value
+
+    @misspellings.setter
+    def misspellings(self,value:str):
+        '''
+            Set the misspellings value.
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 01-06-2023 16:31:05
+            `@memberOf`: PostArg
+            `@property`: misspellings
+        '''
+        self._misspellings = value
 
 
 
